==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerSettingsConsistentHashBuilder extends LoadBalancerSettingsConsistentHashFluentImpl<LoadBalancerSettingsConsistentHashBuilder> implements VisitableBuilder<LoadBalancerSettingsConsistentHash,LoadBalancerSettingsConsistentHashBuilder>{
  public LoadBalancerSettingsConsistentHashBuilder() {
    this(false);
  }
  public LoadBalancerSettingsConsistentHashBuilder(Boolean validationEnabled) {
    this(new LoadBalancerSettingsConsistentHash(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashBuilder(LoadBalancerSettingsConsistentHashFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerSettingsConsistentHashBuilder(LoadBalancerSettingsConsistentHashFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerSettingsConsistentHash(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashBuilder(LoadBalancerSettingsConsistentHashFluent<?> fluent,LoadBalancerSettingsConsistentHash instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerSettingsConsistentHashBuilder(LoadBalancerSettingsConsistentHashFluent<?> fluent,LoadBalancerSettingsConsistentHash instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withConsistentHash(instance.getConsistentHash());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerSettingsConsistentHashBuilder(LoadBalancerSettingsConsistentHash instance) {
    this(instance,false);
  }
  public LoadBalancerSettingsConsistentHashBuilder(LoadBalancerSettingsConsistentHash instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withConsistentHash(instance.getConsistentHash());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerSettingsConsistentHashFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerSettingsConsistentHash build() {
    LoadBalancerSettingsConsistentHash buildable = new LoadBalancerSettingsConsistentHash(fluent.getConsistentHash());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerSettingsConsistentHashBuilder extends LoadBalancerSettingsConsistentHashFluent<LoadBalancerSettingsConsistentHashBuilder> implements VisitableBuilder<LoadBalancerSettingsConsistentHash,LoadBalancerSettingsConsistentHashBuilder>{
  public LoadBalancerSettingsConsistentHashBuilder() {
    this(false);
  }
  public LoadBalancerSettingsConsistentHashBuilder(Boolean validationEnabled) {
    this(new LoadBalancerSettingsConsistentHash(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashBuilder(LoadBalancerSettingsConsistentHashFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerSettingsConsistentHashBuilder(LoadBalancerSettingsConsistentHashFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerSettingsConsistentHash(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashBuilder(LoadBalancerSettingsConsistentHashFluent<?> fluent,LoadBalancerSettingsConsistentHash instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerSettingsConsistentHashBuilder(LoadBalancerSettingsConsistentHashFluent<?> fluent,LoadBalancerSettingsConsistentHash instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHash());

    if (instance != null) {
      fluent.withConsistentHash(instance.getConsistentHash());
      fluent.withConsistentHash(instance.getConsistentHash());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerSettingsConsistentHashBuilder(LoadBalancerSettingsConsistentHash instance) {
    this(instance,false);
  }
  public LoadBalancerSettingsConsistentHashBuilder(LoadBalancerSettingsConsistentHash instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHash());

    if (instance != null) {
      this.withConsistentHash(instance.getConsistentHash());
      this.withConsistentHash(instance.getConsistentHash());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerSettingsConsistentHashFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerSettingsConsistentHash build() {
    LoadBalancerSettingsConsistentHash buildable = new LoadBalancerSettingsConsistentHash(fluent.buildConsistentHash());
    return buildable;
  }
  
}
